from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PostInteractionCountersStory(BaseModel):
    """
    types.PostInteractionCountersStory
    ID: 0x8a480e27
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PostInteractionCountersStory', 'PostInteractionCountersStory'] = pydantic.Field(
        'types.PostInteractionCountersStory',
        alias='_'
    )

    story_id: int
    views: int
    forwards: int
    reactions: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UserProfilePhoto(BaseModel):
    """
    types.UserProfilePhoto
    ID: 0x82d1f706
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UserProfilePhoto', 'UserProfilePhoto'] = pydantic.Field(
        'types.UserProfilePhoto',
        alias='_'
    )

    photo_id: int
    dc_id: int
    has_video: typing.Optional[bool] = None
    personal: typing.Optional[bool] = None
    stripped_thumb: typing.Optional[Bytes] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.EmojiStatuses - Layer 181
EmojiStatuses = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.account.EmojiStatuses,
            pydantic.Tag('account.EmojiStatuses'),
            pydantic.Tag('EmojiStatuses')
        ],
        typing.Annotated[
            types.account.EmojiStatusesNotModified,
            pydantic.Tag('account.EmojiStatusesNotModified'),
            pydantic.Tag('EmojiStatusesNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class User(BaseModel):
    """
    types.User
    ID: 0x215c4438
    Layer: 181
    """
    QUALNAME: typing.Literal['types.User', 'User'] = pydantic.Field(
        'types.User',
        alias='_'
    )

    id: int
    is_self: typing.Optional[bool] = pydantic.Field(
        None,
        serialization_alias='self',
        validation_alias=pydantic.AliasChoices('self', 'is_self')
    )
    contact: typing.Optional[bool] = None
    mutual_contact: typing.Optional[bool] = None
    deleted: typing.Optional[bool] = None
    bot: typing.Optional[bool] = None
    bot_chat_history: typing.Optional[bool] = None
    bot_nochats: typing.Optional[bool] = None
    verified: typing.Optional[bool] = None
    restricted: typing.Optional[bool] = None
    min: typing.Optional[bool] = None
    bot_inline_geo: typing.Optional[bool] = None
    support: typing.Optional[bool] = None
    scam: typing.Optional[bool] = None
    apply_min_photo: typing.Optional[bool] = None
    fake: typing.Optional[bool] = None
    bot_attach_menu: typing.Optional[bool] = None
    premium: typing.Optional[bool] = None
    attach_menu_enabled: typing.Optional[bool] = None
    bot_can_edit: typing.Optional[bool] = None
    close_friend: typing.Optional[bool] = None
    stories_hidden: typing.Optional[bool] = None
    stories_unavailable: typing.Optional[bool] = None
    contact_require_premium: typing.Optional[bool] = None
    bot_business: typing.Optional[bool] = None
    access_hash: typing.Optional[int] = None
    first_name: typing.Optional[str] = None
    last_name: typing.Optional[str] = None
    username: typing.Optional[str] = None
    phone: typing.Optional[str] = None
    photo: typing.Optional["base.UserProfilePhoto"] = None
    status: typing.Optional["base.UserStatus"] = None
    bot_info_version: typing.Optional[int] = None
    restriction_reason: typing.Optional[list["base.RestrictionReason"]] = None
    bot_inline_placeholder: typing.Optional[str] = None
    lang_code: typing.Optional[str] = None
    emoji_status: typing.Optional["base.EmojiStatus"] = None
    usernames: typing.Optional[list["base.Username"]] = None
    stories_max_id: typing.Optional[int] = None
    color: typing.Optional["base.PeerColor"] = None
    profile_color: typing.Optional["base.PeerColor"] = None



from .get_boosts_list import GetBoostsList
from .get_my_boosts import GetMyBoosts
from .apply_boost import ApplyBoost
from .get_boosts_status import GetBoostsStatus
from .get_user_boosts import GetUserBoosts



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Game(BaseModel):
    """
    types.Game
    ID: 0xbdf9653b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Game', 'Game'] = pydantic.Field(
        'types.Game',
        alias='_'
    )

    id: int
    access_hash: int
    short_name: str
    title: str
    description: str
    photo: "base.Photo"
    document: typing.Optional["base.Document"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestedPeerChat(BaseModel):
    """
    types.RequestedPeerChat
    ID: 0x7307544f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.RequestedPeerChat', 'RequestedPeerChat'] = pydantic.Field(
        'types.RequestedPeerChat',
        alias='_'
    )

    chat_id: int
    title: typing.Optional[str] = None
    photo: typing.Optional["base.Photo"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateSavedReactionTag(BaseModel):
    """
    functions.messages.UpdateSavedReactionTag
    ID: 0x60297dec
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.UpdateSavedReactionTag', 'UpdateSavedReactionTag'] = pydantic.Field(
        'functions.messages.UpdateSavedReactionTag',
        alias='_'
    )

    reaction: "base.Reaction"
    title: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Password(BaseModel):
    """
    types.account.Password
    ID: 0x957b50fb
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.Password', 'Password'] = pydantic.Field(
        'types.account.Password',
        alias='_'
    )

    new_algo: "base.PasswordKdfAlgo"
    new_secure_algo: "base.SecurePasswordKdfAlgo"
    secure_random: Bytes
    has_recovery: typing.Optional[bool] = None
    has_secure_values: typing.Optional[bool] = None
    has_password: typing.Optional[bool] = None
    current_algo: typing.Optional["base.PasswordKdfAlgo"] = None
    srp_B: typing.Optional[Bytes] = None
    srp_id: typing.Optional[int] = None
    hint: typing.Optional[str] = None
    email_unconfirmed_pattern: typing.Optional[str] = None
    pending_reset_date: typing.Optional[Datetime] = None
    login_email_pattern: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class NotifyForumTopic(BaseModel):
    """
    types.NotifyForumTopic
    ID: 0x226e6308
    Layer: 181
    """
    QUALNAME: typing.Literal['types.NotifyForumTopic', 'NotifyForumTopic'] = pydantic.Field(
        'types.NotifyForumTopic',
        alias='_'
    )

    peer: "base.Peer"
    top_msg_id: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PeerLocated - Layer 181
PeerLocated = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.PeerLocated,
            pydantic.Tag('PeerLocated')
        ],
        typing.Annotated[
            types.PeerSelfLocated,
            pydantic.Tag('PeerSelfLocated')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class TranscribedAudio(BaseModel):
    """
    types.messages.TranscribedAudio
    ID: 0xcfb9d957
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.TranscribedAudio', 'TranscribedAudio'] = pydantic.Field(
        'types.messages.TranscribedAudio',
        alias='_'
    )

    transcription_id: int
    text: str
    pending: typing.Optional[bool] = None
    trial_remains_num: typing.Optional[int] = None
    trial_remains_until_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StatsGraph - Layer 181
StatsGraph = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.StatsGraph,
            pydantic.Tag('StatsGraph')
        ],
        typing.Annotated[
            types.StatsGraphAsync,
            pydantic.Tag('StatsGraphAsync')
        ],
        typing.Annotated[
            types.StatsGraphError,
            pydantic.Tag('StatsGraphError')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputWebFileGeoPointLocation(BaseModel):
    """
    types.InputWebFileGeoPointLocation
    ID: 0x9f2221c9
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputWebFileGeoPointLocation', 'InputWebFileGeoPointLocation'] = pydantic.Field(
        'types.InputWebFileGeoPointLocation',
        alias='_'
    )

    geo_point: "base.InputGeoPoint"
    access_hash: int
    w: int
    h: int
    zoom: int
    scale: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatlistUpdates(BaseModel):
    """
    types.chatlists.ChatlistUpdates
    ID: 0x93bd878d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.chatlists.ChatlistUpdates', 'ChatlistUpdates'] = pydantic.Field(
        'types.chatlists.ChatlistUpdates',
        alias='_'
    )

    missing_peers: list["base.Peer"]
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PhoneCall - Layer 181
PhoneCall = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.PhoneCall,
            pydantic.Tag('PhoneCall')
        ],
        typing.Annotated[
            types.PhoneCallAccepted,
            pydantic.Tag('PhoneCallAccepted')
        ],
        typing.Annotated[
            types.PhoneCallDiscarded,
            pydantic.Tag('PhoneCallDiscarded')
        ],
        typing.Annotated[
            types.PhoneCallEmpty,
            pydantic.Tag('PhoneCallEmpty')
        ],
        typing.Annotated[
            types.PhoneCallRequested,
            pydantic.Tag('PhoneCallRequested')
        ],
        typing.Annotated[
            types.PhoneCallWaiting,
            pydantic.Tag('PhoneCallWaiting')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Authorization(BaseModel):
    """
    types.Authorization
    ID: 0xad01d61d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Authorization', 'Authorization'] = pydantic.Field(
        'types.Authorization',
        alias='_'
    )

    hash: int
    device_model: str
    platform: str
    system_version: str
    api_id: int
    app_name: str
    app_version: str
    date_created: Datetime
    date_active: Datetime
    ip: str
    country: str
    region: str
    current: typing.Optional[bool] = None
    official_app: typing.Optional[bool] = None
    password_pending: typing.Optional[bool] = None
    encrypted_requests_disabled: typing.Optional[bool] = None
    call_requests_disabled: typing.Optional[bool] = None
    unconfirmed: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PaymentReceipt(BaseModel):
    """
    types.payments.PaymentReceipt
    ID: 0x70c4fe03
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.PaymentReceipt', 'PaymentReceipt'] = pydantic.Field(
        'types.payments.PaymentReceipt',
        alias='_'
    )

    date: Datetime
    bot_id: int
    provider_id: int
    title: str
    description: str
    invoice: "base.Invoice"
    currency: str
    total_amount: int
    credentials_title: str
    users: list["base.User"]
    photo: typing.Optional["base.WebDocument"] = None
    info: typing.Optional["base.PaymentRequestedInfo"] = None
    shipping: typing.Optional["base.ShippingOption"] = None
    tip_amount: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ResolvedBusinessChatLinks(BaseModel):
    """
    types.account.ResolvedBusinessChatLinks
    ID: 0x9a23af21
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.ResolvedBusinessChatLinks', 'ResolvedBusinessChatLinks'] = pydantic.Field(
        'types.account.ResolvedBusinessChatLinks',
        alias='_'
    )

    peer: "base.Peer"
    message: str
    chats: list["base.Chat"]
    users: list["base.User"]
    entities: typing.Optional[list["base.MessageEntity"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.Chats - Layer 181
Chats = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.Chats,
            pydantic.Tag('messages.Chats'),
            pydantic.Tag('Chats')
        ],
        typing.Annotated[
            types.messages.ChatsSlice,
            pydantic.Tag('messages.ChatsSlice'),
            pydantic.Tag('ChatsSlice')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatFull(BaseModel):
    """
    types.messages.ChatFull
    ID: 0xe5d7d19c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.ChatFull', 'ChatFull'] = pydantic.Field(
        'types.messages.ChatFull',
        alias='_'
    )

    full_chat: "base.ChatFull"
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageBlockSlideshow(BaseModel):
    """
    types.PageBlockSlideshow
    ID: 0x31f9590
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageBlockSlideshow', 'PageBlockSlideshow'] = pydantic.Field(
        'types.PageBlockSlideshow',
        alias='_'
    )

    items: list["base.PageBlock"]
    caption: "base.PageCaption"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StoryViewPublicRepost(BaseModel):
    """
    types.StoryViewPublicRepost
    ID: 0xbd74cf49
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StoryViewPublicRepost', 'StoryViewPublicRepost'] = pydantic.Field(
        'types.StoryViewPublicRepost',
        alias='_'
    )

    peer_id: "base.Peer"
    story: "base.StoryItem"
    blocked: typing.Optional[bool] = None
    blocked_my_stories_from: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class NearestDc(BaseModel):
    """
    types.NearestDc
    ID: 0x8e1a1775
    Layer: 181
    """
    QUALNAME: typing.Literal['types.NearestDc', 'NearestDc'] = pydantic.Field(
        'types.NearestDc',
        alias='_'
    )

    country: str
    this_dc: int
    nearest_dc: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateReadMessagesContents(BaseModel):
    """
    types.UpdateReadMessagesContents
    ID: 0xf8227181
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateReadMessagesContents', 'UpdateReadMessagesContents'] = pydantic.Field(
        'types.UpdateReadMessagesContents',
        alias='_'
    )

    messages: list[int]
    pts: int
    pts_count: int
    date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Update - Layer 181
Update = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.UpdateAttachMenuBots,
            pydantic.Tag('UpdateAttachMenuBots')
        ],
        typing.Annotated[
            types.UpdateAutoSaveSettings,
            pydantic.Tag('UpdateAutoSaveSettings')
        ],
        typing.Annotated[
            types.UpdateBotBusinessConnect,
            pydantic.Tag('UpdateBotBusinessConnect')
        ],
        typing.Annotated[
            types.UpdateBotCallbackQuery,
            pydantic.Tag('UpdateBotCallbackQuery')
        ],
        typing.Annotated[
            types.UpdateBotChatBoost,
            pydantic.Tag('UpdateBotChatBoost')
        ],
        typing.Annotated[
            types.UpdateBotChatInviteRequester,
            pydantic.Tag('UpdateBotChatInviteRequester')
        ],
        typing.Annotated[
            types.UpdateBotCommands,
            pydantic.Tag('UpdateBotCommands')
        ],
        typing.Annotated[
            types.UpdateBotDeleteBusinessMessage,
            pydantic.Tag('UpdateBotDeleteBusinessMessage')
        ],
        typing.Annotated[
            types.UpdateBotEditBusinessMessage,
            pydantic.Tag('UpdateBotEditBusinessMessage')
        ],
        typing.Annotated[
            types.UpdateBotInlineQuery,
            pydantic.Tag('UpdateBotInlineQuery')
        ],
        typing.Annotated[
            types.UpdateBotInlineSend,
            pydantic.Tag('UpdateBotInlineSend')
        ],
        typing.Annotated[
            types.UpdateBotMenuButton,
            pydantic.Tag('UpdateBotMenuButton')
        ],
        typing.Annotated[
            types.UpdateBotMessageReaction,
            pydantic.Tag('UpdateBotMessageReaction')
        ],
        typing.Annotated[
            types.UpdateBotMessageReactions,
            pydantic.Tag('UpdateBotMessageReactions')
        ],
        typing.Annotated[
            types.UpdateBotNewBusinessMessage,
            pydantic.Tag('UpdateBotNewBusinessMessage')
        ],
        typing.Annotated[
            types.UpdateBotPrecheckoutQuery,
            pydantic.Tag('UpdateBotPrecheckoutQuery')
        ],
        typing.Annotated[
            types.UpdateBotShippingQuery,
            pydantic.Tag('UpdateBotShippingQuery')
        ],
        typing.Annotated[
            types.UpdateBotStopped,
            pydantic.Tag('UpdateBotStopped')
        ],
        typing.Annotated[
            types.UpdateBotWebhookJSON,
            pydantic.Tag('UpdateBotWebhookJSON')
        ],
        typing.Annotated[
            types.UpdateBotWebhookJSONQuery,
            pydantic.Tag('UpdateBotWebhookJSONQuery')
        ],
        typing.Annotated[
            types.UpdateBroadcastRevenueTransactions,
            pydantic.Tag('UpdateBroadcastRevenueTransactions')
        ],
        typing.Annotated[
            types.UpdateChannel,
            pydantic.Tag('UpdateChannel')
        ],
        typing.Annotated[
            types.UpdateChannelAvailableMessages,
            pydantic.Tag('UpdateChannelAvailableMessages')
        ],
        typing.Annotated[
            types.UpdateChannelMessageForwards,
            pydantic.Tag('UpdateChannelMessageForwards')
        ],
        typing.Annotated[
            types.UpdateChannelMessageViews,
            pydantic.Tag('UpdateChannelMessageViews')
        ],
        typing.Annotated[
            types.UpdateChannelParticipant,
            pydantic.Tag('UpdateChannelParticipant')
        ],
        typing.Annotated[
            types.UpdateChannelPinnedTopic,
            pydantic.Tag('UpdateChannelPinnedTopic')
        ],
        typing.Annotated[
            types.UpdateChannelPinnedTopics,
            pydantic.Tag('UpdateChannelPinnedTopics')
        ],
        typing.Annotated[
            types.UpdateChannelReadMessagesContents,
            pydantic.Tag('UpdateChannelReadMessagesContents')
        ],
        typing.Annotated[
            types.UpdateChannelTooLong,
            pydantic.Tag('UpdateChannelTooLong')
        ],
        typing.Annotated[
            types.UpdateChannelUserTyping,
            pydantic.Tag('UpdateChannelUserTyping')
        ],
        typing.Annotated[
            types.UpdateChannelViewForumAsMessages,
            pydantic.Tag('UpdateChannelViewForumAsMessages')
        ],
        typing.Annotated[
            types.UpdateChannelWebPage,
            pydantic.Tag('UpdateChannelWebPage')
        ],
        typing.Annotated[
            types.UpdateChat,
            pydantic.Tag('UpdateChat')
        ],
        typing.Annotated[
            types.UpdateChatDefaultBannedRights,
            pydantic.Tag('UpdateChatDefaultBannedRights')
        ],
        typing.Annotated[
            types.UpdateChatParticipant,
            pydantic.Tag('UpdateChatParticipant')
        ],
        typing.Annotated[
            types.UpdateChatParticipantAdd,
            pydantic.Tag('UpdateChatParticipantAdd')
        ],
        typing.Annotated[
            types.UpdateChatParticipantAdmin,
            pydantic.Tag('UpdateChatParticipantAdmin')
        ],
        typing.Annotated[
            types.UpdateChatParticipantDelete,
            pydantic.Tag('UpdateChatParticipantDelete')
        ],
        typing.Annotated[
            types.UpdateChatParticipants,
            pydantic.Tag('UpdateChatParticipants')
        ],
        typing.Annotated[
            types.UpdateChatUserTyping,
            pydantic.Tag('UpdateChatUserTyping')
        ],
        typing.Annotated[
            types.UpdateConfig,
            pydantic.Tag('UpdateConfig')
        ],
        typing.Annotated[
            types.UpdateContactsReset,
            pydantic.Tag('UpdateContactsReset')
        ],
        typing.Annotated[
            types.UpdateDcOptions,
            pydantic.Tag('UpdateDcOptions')
        ],
        typing.Annotated[
            types.UpdateDeleteChannelMessages,
            pydantic.Tag('UpdateDeleteChannelMessages')
        ],
        typing.Annotated[
            types.UpdateDeleteMessages,
            pydantic.Tag('UpdateDeleteMessages')
        ],
        typing.Annotated[
            types.UpdateDeleteQuickReply,
            pydantic.Tag('UpdateDeleteQuickReply')
        ],
        typing.Annotated[
            types.UpdateDeleteQuickReplyMessages,
            pydantic.Tag('UpdateDeleteQuickReplyMessages')
        ],
        typing.Annotated[
            types.UpdateDeleteScheduledMessages,
            pydantic.Tag('UpdateDeleteScheduledMessages')
        ],
        typing.Annotated[
            types.UpdateDialogFilter,
            pydantic.Tag('UpdateDialogFilter')
        ],
        typing.Annotated[
            types.UpdateDialogFilterOrder,
            pydantic.Tag('UpdateDialogFilterOrder')
        ],
        typing.Annotated[
            types.UpdateDialogFilters,
            pydantic.Tag('UpdateDialogFilters')
        ],
        typing.Annotated[
            types.UpdateDialogPinned,
            pydantic.Tag('UpdateDialogPinned')
        ],
        typing.Annotated[
            types.UpdateDialogUnreadMark,
            pydantic.Tag('UpdateDialogUnreadMark')
        ],
        typing.Annotated[
            types.UpdateDraftMessage,
            pydantic.Tag('UpdateDraftMessage')
        ],
        typing.Annotated[
            types.UpdateEditChannelMessage,
            pydantic.Tag('UpdateEditChannelMessage')
        ],
        typing.Annotated[
            types.UpdateEditMessage,
            pydantic.Tag('UpdateEditMessage')
        ],
        typing.Annotated[
            types.UpdateEncryptedChatTyping,
            pydantic.Tag('UpdateEncryptedChatTyping')
        ],
        typing.Annotated[
            types.UpdateEncryptedMessagesRead,
            pydantic.Tag('UpdateEncryptedMessagesRead')
        ],
        typing.Annotated[
            types.UpdateEncryption,
            pydantic.Tag('UpdateEncryption')
        ],
        typing.Annotated[
            types.UpdateFavedStickers,
            pydantic.Tag('UpdateFavedStickers')
        ],
        typing.Annotated[
            types.UpdateFolderPeers,
            pydantic.Tag('UpdateFolderPeers')
        ],
        typing.Annotated[
            types.UpdateGeoLiveViewed,
            pydantic.Tag('UpdateGeoLiveViewed')
        ],
        typing.Annotated[
            types.UpdateGroupCall,
            pydantic.Tag('UpdateGroupCall')
        ],
        typing.Annotated[
            types.UpdateGroupCallConnection,
            pydantic.Tag('UpdateGroupCallConnection')
        ],
        typing.Annotated[
            types.UpdateGroupCallParticipants,
            pydantic.Tag('UpdateGroupCallParticipants')
        ],
        typing.Annotated[
            types.UpdateInlineBotCallbackQuery,
            pydantic.Tag('UpdateInlineBotCallbackQuery')
        ],
        typing.Annotated[
            types.UpdateLangPack,
            pydantic.Tag('UpdateLangPack')
        ],
        typing.Annotated[
            types.UpdateLangPackTooLong,
            pydantic.Tag('UpdateLangPackTooLong')
        ],
        typing.Annotated[
            types.UpdateLoginToken,
            pydantic.Tag('UpdateLoginToken')
        ],
        typing.Annotated[
            types.UpdateMessageExtendedMedia,
            pydantic.Tag('UpdateMessageExtendedMedia')
        ],
        typing.Annotated[
            types.UpdateMessageID,
            pydantic.Tag('UpdateMessageID')
        ],
        typing.Annotated[
            types.UpdateMessagePoll,
            pydantic.Tag('UpdateMessagePoll')
        ],
        typing.Annotated[
            types.UpdateMessagePollVote,
            pydantic.Tag('UpdateMessagePollVote')
        ],
        typing.Annotated[
            types.UpdateMessageReactions,
            pydantic.Tag('UpdateMessageReactions')
        ],
        typing.Annotated[
            types.UpdateMoveStickerSetToTop,
            pydantic.Tag('UpdateMoveStickerSetToTop')
        ],
        typing.Annotated[
            types.UpdateNewAuthorization,
            pydantic.Tag('UpdateNewAuthorization')
        ],
        typing.Annotated[
            types.UpdateNewChannelMessage,
            pydantic.Tag('UpdateNewChannelMessage')
        ],
        typing.Annotated[
            types.UpdateNewEncryptedMessage,
            pydantic.Tag('UpdateNewEncryptedMessage')
        ],
        typing.Annotated[
            types.UpdateNewMessage,
            pydantic.Tag('UpdateNewMessage')
        ],
        typing.Annotated[
            types.UpdateNewQuickReply,
            pydantic.Tag('UpdateNewQuickReply')
        ],
        typing.Annotated[
            types.UpdateNewScheduledMessage,
            pydantic.Tag('UpdateNewScheduledMessage')
        ],
        typing.Annotated[
            types.UpdateNewStickerSet,
            pydantic.Tag('UpdateNewStickerSet')
        ],
        typing.Annotated[
            types.UpdateNewStoryReaction,
            pydantic.Tag('UpdateNewStoryReaction')
        ],
        typing.Annotated[
            types.UpdateNotifySettings,
            pydantic.Tag('UpdateNotifySettings')
        ],
        typing.Annotated[
            types.UpdatePeerBlocked,
            pydantic.Tag('UpdatePeerBlocked')
        ],
        typing.Annotated[
            types.UpdatePeerHistoryTTL,
            pydantic.Tag('UpdatePeerHistoryTTL')
        ],
        typing.Annotated[
            types.UpdatePeerLocated,
            pydantic.Tag('UpdatePeerLocated')
        ],
        typing.Annotated[
            types.UpdatePeerSettings,
            pydantic.Tag('UpdatePeerSettings')
        ],
        typing.Annotated[
            types.UpdatePeerWallpaper,
            pydantic.Tag('UpdatePeerWallpaper')
        ],
        typing.Annotated[
            types.UpdatePendingJoinRequests,
            pydantic.Tag('UpdatePendingJoinRequests')
        ],
        typing.Annotated[
            types.UpdatePhoneCall,
            pydantic.Tag('UpdatePhoneCall')
        ],
        typing.Annotated[
            types.UpdatePhoneCallSignalingData,
            pydantic.Tag('UpdatePhoneCallSignalingData')
        ],
        typing.Annotated[
            types.UpdatePinnedChannelMessages,
            pydantic.Tag('UpdatePinnedChannelMessages')
        ],
        typing.Annotated[
            types.UpdatePinnedDialogs,
            pydantic.Tag('UpdatePinnedDialogs')
        ],
        typing.Annotated[
            types.UpdatePinnedMessages,
            pydantic.Tag('UpdatePinnedMessages')
        ],
        typing.Annotated[
            types.UpdatePinnedSavedDialogs,
            pydantic.Tag('UpdatePinnedSavedDialogs')
        ],
        typing.Annotated[
            types.UpdatePrivacy,
            pydantic.Tag('UpdatePrivacy')
        ],
        typing.Annotated[
            types.UpdatePtsChanged,
            pydantic.Tag('UpdatePtsChanged')
        ],
        typing.Annotated[
            types.UpdateQuickReplies,
            pydantic.Tag('UpdateQuickReplies')
        ],
        typing.Annotated[
            types.UpdateQuickReplyMessage,
            pydantic.Tag('UpdateQuickReplyMessage')
        ],
        typing.Annotated[
            types.UpdateReadChannelDiscussionInbox,
            pydantic.Tag('UpdateReadChannelDiscussionInbox')
        ],
        typing.Annotated[
            types.UpdateReadChannelDiscussionOutbox,
            pydantic.Tag('UpdateReadChannelDiscussionOutbox')
        ],
        typing.Annotated[
            types.UpdateReadChannelInbox,
            pydantic.Tag('UpdateReadChannelInbox')
        ],
        typing.Annotated[
            types.UpdateReadChannelOutbox,
            pydantic.Tag('UpdateReadChannelOutbox')
        ],
        typing.Annotated[
            types.UpdateReadFeaturedEmojiStickers,
            pydantic.Tag('UpdateReadFeaturedEmojiStickers')
        ],
        typing.Annotated[
            types.UpdateReadFeaturedStickers,
            pydantic.Tag('UpdateReadFeaturedStickers')
        ],
        typing.Annotated[
            types.UpdateReadHistoryInbox,
            pydantic.Tag('UpdateReadHistoryInbox')
        ],
        typing.Annotated[
            types.UpdateReadHistoryOutbox,
            pydantic.Tag('UpdateReadHistoryOutbox')
        ],
        typing.Annotated[
            types.UpdateReadMessagesContents,
            pydantic.Tag('UpdateReadMessagesContents')
        ],
        typing.Annotated[
            types.UpdateReadStories,
            pydantic.Tag('UpdateReadStories')
        ],
        typing.Annotated[
            types.UpdateRecentEmojiStatuses,
            pydantic.Tag('UpdateRecentEmojiStatuses')
        ],
        typing.Annotated[
            types.UpdateRecentReactions,
            pydantic.Tag('UpdateRecentReactions')
        ],
        typing.Annotated[
            types.UpdateRecentStickers,
            pydantic.Tag('UpdateRecentStickers')
        ],
        typing.Annotated[
            types.UpdateSavedDialogPinned,
            pydantic.Tag('UpdateSavedDialogPinned')
        ],
        typing.Annotated[
            types.UpdateSavedGifs,
            pydantic.Tag('UpdateSavedGifs')
        ],
        typing.Annotated[
            types.UpdateSavedReactionTags,
            pydantic.Tag('UpdateSavedReactionTags')
        ],
        typing.Annotated[
            types.UpdateSavedRingtones,
            pydantic.Tag('UpdateSavedRingtones')
        ],
        typing.Annotated[
            types.UpdateSentStoryReaction,
            pydantic.Tag('UpdateSentStoryReaction')
        ],
        typing.Annotated[
            types.UpdateServiceNotification,
            pydantic.Tag('UpdateServiceNotification')
        ],
        typing.Annotated[
            types.UpdateSmsJob,
            pydantic.Tag('UpdateSmsJob')
        ],
        typing.Annotated[
            types.UpdateStarsBalance,
            pydantic.Tag('UpdateStarsBalance')
        ],
        typing.Annotated[
            types.UpdateStickerSets,
            pydantic.Tag('UpdateStickerSets')
        ],
        typing.Annotated[
            types.UpdateStickerSetsOrder,
            pydantic.Tag('UpdateStickerSetsOrder')
        ],
        typing.Annotated[
            types.UpdateStoriesStealthMode,
            pydantic.Tag('UpdateStoriesStealthMode')
        ],
        typing.Annotated[
            types.UpdateStory,
            pydantic.Tag('UpdateStory')
        ],
        typing.Annotated[
            types.UpdateStoryID,
            pydantic.Tag('UpdateStoryID')
        ],
        typing.Annotated[
            types.UpdateTheme,
            pydantic.Tag('UpdateTheme')
        ],
        typing.Annotated[
            types.UpdateTranscribedAudio,
            pydantic.Tag('UpdateTranscribedAudio')
        ],
        typing.Annotated[
            types.UpdateUser,
            pydantic.Tag('UpdateUser')
        ],
        typing.Annotated[
            types.UpdateUserEmojiStatus,
            pydantic.Tag('UpdateUserEmojiStatus')
        ],
        typing.Annotated[
            types.UpdateUserName,
            pydantic.Tag('UpdateUserName')
        ],
        typing.Annotated[
            types.UpdateUserPhone,
            pydantic.Tag('UpdateUserPhone')
        ],
        typing.Annotated[
            types.UpdateUserStatus,
            pydantic.Tag('UpdateUserStatus')
        ],
        typing.Annotated[
            types.UpdateUserTyping,
            pydantic.Tag('UpdateUserTyping')
        ],
        typing.Annotated[
            types.UpdateWebPage,
            pydantic.Tag('UpdateWebPage')
        ],
        typing.Annotated[
            types.UpdateWebViewResultSent,
            pydantic.Tag('UpdateWebViewResultSent')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.AppUpdate - Layer 181
AppUpdate = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.help.AppUpdate,
            pydantic.Tag('help.AppUpdate'),
            pydantic.Tag('AppUpdate')
        ],
        typing.Annotated[
            types.help.NoAppUpdate,
            pydantic.Tag('help.NoAppUpdate'),
            pydantic.Tag('NoAppUpdate')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageMediaVenue(BaseModel):
    """
    types.MessageMediaVenue
    ID: 0x2ec0533f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageMediaVenue', 'MessageMediaVenue'] = pydantic.Field(
        'types.MessageMediaVenue',
        alias='_'
    )

    geo: "base.GeoPoint"
    title: str
    address: str
    provider: str
    venue_id: str
    venue_type: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetAuthorizationTTL(BaseModel):
    """
    functions.account.SetAuthorizationTTL
    ID: 0xbf899aa0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.SetAuthorizationTTL', 'SetAuthorizationTTL'] = pydantic.Field(
        'functions.account.SetAuthorizationTTL',
        alias='_'
    )

    authorization_ttl_days: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelAdminLogEvent(BaseModel):
    """
    types.ChannelAdminLogEvent
    ID: 0x1fad68cd
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelAdminLogEvent', 'ChannelAdminLogEvent'] = pydantic.Field(
        'types.ChannelAdminLogEvent',
        alias='_'
    )

    id: int
    date: Datetime
    user_id: int
    action: "base.ChannelAdminLogEventAction"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateShort(BaseModel):
    """
    types.UpdateShort
    ID: 0x78d4dec1
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateShort', 'UpdateShort'] = pydantic.Field(
        'types.UpdateShort',
        alias='_'
    )

    update: "base.Update"
    date: Datetime



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BotInlineMessageMediaVenue(BaseModel):
    """
    types.BotInlineMessageMediaVenue
    ID: 0x8a86659c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BotInlineMessageMediaVenue', 'BotInlineMessageMediaVenue'] = pydantic.Field(
        'types.BotInlineMessageMediaVenue',
        alias='_'
    )

    geo: "base.GeoPoint"
    title: str
    address: str
    provider: str
    venue_id: str
    venue_type: str
    reply_markup: typing.Optional["base.ReplyMarkup"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AcceptAuthorization(BaseModel):
    """
    functions.account.AcceptAuthorization
    ID: 0xf3ed4c73
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.AcceptAuthorization', 'AcceptAuthorization'] = pydantic.Field(
        'functions.account.AcceptAuthorization',
        alias='_'
    )

    bot_id: int
    scope: str
    public_key: str
    value_hashes: list["base.SecureValueHash"]
    credentials: "base.SecureCredentialsEncrypted"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WebPageEmpty(BaseModel):
    """
    types.WebPageEmpty
    ID: 0x211a1788
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WebPageEmpty', 'WebPageEmpty'] = pydantic.Field(
        'types.WebPageEmpty',
        alias='_'
    )

    id: int
    url: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# KeyboardButton - Layer 181
KeyboardButton = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputKeyboardButtonRequestPeer,
            pydantic.Tag('InputKeyboardButtonRequestPeer')
        ],
        typing.Annotated[
            types.InputKeyboardButtonUrlAuth,
            pydantic.Tag('InputKeyboardButtonUrlAuth')
        ],
        typing.Annotated[
            types.InputKeyboardButtonUserProfile,
            pydantic.Tag('InputKeyboardButtonUserProfile')
        ],
        typing.Annotated[
            types.KeyboardButton,
            pydantic.Tag('KeyboardButton')
        ],
        typing.Annotated[
            types.KeyboardButtonBuy,
            pydantic.Tag('KeyboardButtonBuy')
        ],
        typing.Annotated[
            types.KeyboardButtonCallback,
            pydantic.Tag('KeyboardButtonCallback')
        ],
        typing.Annotated[
            types.KeyboardButtonGame,
            pydantic.Tag('KeyboardButtonGame')
        ],
        typing.Annotated[
            types.KeyboardButtonRequestGeoLocation,
            pydantic.Tag('KeyboardButtonRequestGeoLocation')
        ],
        typing.Annotated[
            types.KeyboardButtonRequestPeer,
            pydantic.Tag('KeyboardButtonRequestPeer')
        ],
        typing.Annotated[
            types.KeyboardButtonRequestPhone,
            pydantic.Tag('KeyboardButtonRequestPhone')
        ],
        typing.Annotated[
            types.KeyboardButtonRequestPoll,
            pydantic.Tag('KeyboardButtonRequestPoll')
        ],
        typing.Annotated[
            types.KeyboardButtonSimpleWebView,
            pydantic.Tag('KeyboardButtonSimpleWebView')
        ],
        typing.Annotated[
            types.KeyboardButtonSwitchInline,
            pydantic.Tag('KeyboardButtonSwitchInline')
        ],
        typing.Annotated[
            types.KeyboardButtonUrl,
            pydantic.Tag('KeyboardButtonUrl')
        ],
        typing.Annotated[
            types.KeyboardButtonUrlAuth,
            pydantic.Tag('KeyboardButtonUrlAuth')
        ],
        typing.Annotated[
            types.KeyboardButtonUserProfile,
            pydantic.Tag('KeyboardButtonUserProfile')
        ],
        typing.Annotated[
            types.KeyboardButtonWebView,
            pydantic.Tag('KeyboardButtonWebView')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AcceptCall(BaseModel):
    """
    functions.phone.AcceptCall
    ID: 0x3bd2b4a0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.AcceptCall', 'AcceptCall'] = pydantic.Field(
        'functions.phone.AcceptCall',
        alias='_'
    )

    peer: "base.InputPhoneCall"
    g_b: Bytes
    protocol: "base.PhoneCallProtocol"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class TopPeerCategoryPeers(BaseModel):
    """
    types.TopPeerCategoryPeers
    ID: 0xfb834291
    Layer: 181
    """
    QUALNAME: typing.Literal['types.TopPeerCategoryPeers', 'TopPeerCategoryPeers'] = pydantic.Field(
        'types.TopPeerCategoryPeers',
        alias='_'
    )

    category: "base.TopPeerCategory"
    count: int
    peers: list["base.TopPeer"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetChatWallPaper(BaseModel):
    """
    functions.messages.SetChatWallPaper
    ID: 0x8ffacae1
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SetChatWallPaper', 'SetChatWallPaper'] = pydantic.Field(
        'functions.messages.SetChatWallPaper',
        alias='_'
    )

    peer: "base.InputPeer"
    for_both: typing.Optional[bool] = None
    revert: typing.Optional[bool] = None
    wallpaper: typing.Optional["base.InputWallPaper"] = None
    settings: typing.Optional["base.WallPaperSettings"] = None
    id: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputUser - Layer 181
InputUser = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputUser,
            pydantic.Tag('InputUser')
        ],
        typing.Annotated[
            types.InputUserEmpty,
            pydantic.Tag('InputUserEmpty')
        ],
        typing.Annotated[
            types.InputUserFromMessage,
            pydantic.Tag('InputUserFromMessage')
        ],
        typing.Annotated[
            types.InputUserSelf,
            pydantic.Tag('InputUserSelf')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateWebPage(BaseModel):
    """
    types.UpdateWebPage
    ID: 0x7f891213
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateWebPage', 'UpdateWebPage'] = pydantic.Field(
        'types.UpdateWebPage',
        alias='_'
    )

    webpage: "base.WebPage"
    pts: int
    pts_count: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# storage.FileType - Layer 181
FileType = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.storage.FileGif,
            pydantic.Tag('storage.FileGif'),
            pydantic.Tag('FileGif')
        ],
        typing.Annotated[
            types.storage.FileJpeg,
            pydantic.Tag('storage.FileJpeg'),
            pydantic.Tag('FileJpeg')
        ],
        typing.Annotated[
            types.storage.FileMov,
            pydantic.Tag('storage.FileMov'),
            pydantic.Tag('FileMov')
        ],
        typing.Annotated[
            types.storage.FileMp3,
            pydantic.Tag('storage.FileMp3'),
            pydantic.Tag('FileMp3')
        ],
        typing.Annotated[
            types.storage.FileMp4,
            pydantic.Tag('storage.FileMp4'),
            pydantic.Tag('FileMp4')
        ],
        typing.Annotated[
            types.storage.FilePartial,
            pydantic.Tag('storage.FilePartial'),
            pydantic.Tag('FilePartial')
        ],
        typing.Annotated[
            types.storage.FilePdf,
            pydantic.Tag('storage.FilePdf'),
            pydantic.Tag('FilePdf')
        ],
        typing.Annotated[
            types.storage.FilePng,
            pydantic.Tag('storage.FilePng'),
            pydantic.Tag('FilePng')
        ],
        typing.Annotated[
            types.storage.FileUnknown,
            pydantic.Tag('storage.FileUnknown'),
            pydantic.Tag('FileUnknown')
        ],
        typing.Annotated[
            types.storage.FileWebp,
            pydantic.Tag('storage.FileWebp'),
            pydantic.Tag('FileWebp')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StickerSetCovered - Layer 181
StickerSetCovered = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.StickerSetCovered,
            pydantic.Tag('StickerSetCovered')
        ],
        typing.Annotated[
            types.StickerSetFullCovered,
            pydantic.Tag('StickerSetFullCovered')
        ],
        typing.Annotated[
            types.StickerSetMultiCovered,
            pydantic.Tag('StickerSetMultiCovered')
        ],
        typing.Annotated[
            types.StickerSetNoCovered,
            pydantic.Tag('StickerSetNoCovered')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DeleteChatUser(BaseModel):
    """
    functions.messages.DeleteChatUser
    ID: 0xa2185cab
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.DeleteChatUser', 'DeleteChatUser'] = pydantic.Field(
        'functions.messages.DeleteChatUser',
        alias='_'
    )

    chat_id: int
    user_id: "base.InputUser"
    revoke_history: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessageMedia - Layer 181
MessageMedia = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.MessageMediaContact,
            pydantic.Tag('MessageMediaContact')
        ],
        typing.Annotated[
            types.MessageMediaDice,
            pydantic.Tag('MessageMediaDice')
        ],
        typing.Annotated[
            types.MessageMediaDocument,
            pydantic.Tag('MessageMediaDocument')
        ],
        typing.Annotated[
            types.MessageMediaEmpty,
            pydantic.Tag('MessageMediaEmpty')
        ],
        typing.Annotated[
            types.MessageMediaGame,
            pydantic.Tag('MessageMediaGame')
        ],
        typing.Annotated[
            types.MessageMediaGeo,
            pydantic.Tag('MessageMediaGeo')
        ],
        typing.Annotated[
            types.MessageMediaGeoLive,
            pydantic.Tag('MessageMediaGeoLive')
        ],
        typing.Annotated[
            types.MessageMediaGiveaway,
            pydantic.Tag('MessageMediaGiveaway')
        ],
        typing.Annotated[
            types.MessageMediaGiveawayResults,
            pydantic.Tag('MessageMediaGiveawayResults')
        ],
        typing.Annotated[
            types.MessageMediaInvoice,
            pydantic.Tag('MessageMediaInvoice')
        ],
        typing.Annotated[
            types.MessageMediaPhoto,
            pydantic.Tag('MessageMediaPhoto')
        ],
        typing.Annotated[
            types.MessageMediaPoll,
            pydantic.Tag('MessageMediaPoll')
        ],
        typing.Annotated[
            types.MessageMediaStory,
            pydantic.Tag('MessageMediaStory')
        ],
        typing.Annotated[
            types.MessageMediaUnsupported,
            pydantic.Tag('MessageMediaUnsupported')
        ],
        typing.Annotated[
            types.MessageMediaVenue,
            pydantic.Tag('MessageMediaVenue')
        ],
        typing.Annotated[
            types.MessageMediaWebPage,
            pydantic.Tag('MessageMediaWebPage')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DocumentAttributeAudio(BaseModel):
    """
    types.DocumentAttributeAudio
    ID: 0x9852f9c6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.DocumentAttributeAudio', 'DocumentAttributeAudio'] = pydantic.Field(
        'types.DocumentAttributeAudio',
        alias='_'
    )

    duration: int
    voice: typing.Optional[bool] = None
    title: typing.Optional[str] = None
    performer: typing.Optional[str] = None
    waveform: typing.Optional[Bytes] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SaveBigFilePart(BaseModel):
    """
    functions.upload.SaveBigFilePart
    ID: 0xde7b673d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.upload.SaveBigFilePart', 'SaveBigFilePart'] = pydantic.Field(
        'functions.upload.SaveBigFilePart',
        alias='_'
    )

    file_id: int
    file_part: int
    file_total_parts: int
    bytes: Bytes



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InitTakeoutSession(BaseModel):
    """
    functions.account.InitTakeoutSession
    ID: 0x8ef3eab0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.InitTakeoutSession', 'InitTakeoutSession'] = pydantic.Field(
        'functions.account.InitTakeoutSession',
        alias='_'
    )

    contacts: typing.Optional[bool] = None
    message_users: typing.Optional[bool] = None
    message_chats: typing.Optional[bool] = None
    message_megagroups: typing.Optional[bool] = None
    message_channels: typing.Optional[bool] = None
    files: typing.Optional[bool] = None
    file_max_size: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetNotifyExceptions(BaseModel):
    """
    functions.account.GetNotifyExceptions
    ID: 0x53577479
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.GetNotifyExceptions', 'GetNotifyExceptions'] = pydantic.Field(
        'functions.account.GetNotifyExceptions',
        alias='_'
    )

    compare_sound: typing.Optional[bool] = None
    compare_stories: typing.Optional[bool] = None
    peer: typing.Optional["base.InputNotifyPeer"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetBotCommands(BaseModel):
    """
    functions.bots.SetBotCommands
    ID: 0x517165a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.bots.SetBotCommands', 'SetBotCommands'] = pydantic.Field(
        'functions.bots.SetBotCommands',
        alias='_'
    )

    scope: "base.BotCommandScope"
    lang_code: str
    commands: list["base.BotCommand"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReactionsNotifySettings(BaseModel):
    """
    types.ReactionsNotifySettings
    ID: 0x56e34970
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ReactionsNotifySettings', 'ReactionsNotifySettings'] = pydantic.Field(
        'types.ReactionsNotifySettings',
        alias='_'
    )

    sound: "base.NotificationSound"
    show_previews: bool
    messages_notify_from: typing.Optional["base.ReactionNotificationsFrom"] = None
    stories_notify_from: typing.Optional["base.ReactionNotificationsFrom"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# VideoSize - Layer 181
VideoSize = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.VideoSize,
            pydantic.Tag('VideoSize')
        ],
        typing.Annotated[
            types.VideoSizeEmojiMarkup,
            pydantic.Tag('VideoSizeEmojiMarkup')
        ],
        typing.Annotated[
            types.VideoSizeStickerMarkup,
            pydantic.Tag('VideoSizeStickerMarkup')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class KeyboardButtonSwitchInline(BaseModel):
    """
    types.KeyboardButtonSwitchInline
    ID: 0x93b9fbb5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.KeyboardButtonSwitchInline', 'KeyboardButtonSwitchInline'] = pydantic.Field(
        'types.KeyboardButtonSwitchInline',
        alias='_'
    )

    text: str
    query: str
    same_peer: typing.Optional[bool] = None
    peer_types: typing.Optional[list["base.InlineQueryPeerType"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.ResetPasswordResult - Layer 181
ResetPasswordResult = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.account.ResetPasswordFailedWait,
            pydantic.Tag('account.ResetPasswordFailedWait'),
            pydantic.Tag('ResetPasswordFailedWait')
        ],
        typing.Annotated[
            types.account.ResetPasswordOk,
            pydantic.Tag('account.ResetPasswordOk'),
            pydantic.Tag('ResetPasswordOk')
        ],
        typing.Annotated[
            types.account.ResetPasswordRequestedWait,
            pydantic.Tag('account.ResetPasswordRequestedWait'),
            pydantic.Tag('ResetPasswordRequestedWait')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetAuthorizationForm(BaseModel):
    """
    functions.account.GetAuthorizationForm
    ID: 0xa929597a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.GetAuthorizationForm', 'GetAuthorizationForm'] = pydantic.Field(
        'functions.account.GetAuthorizationForm',
        alias='_'
    )

    bot_id: int
    scope: str
    public_key: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdatePinnedDialogs(BaseModel):
    """
    types.UpdatePinnedDialogs
    ID: 0xfa0f3ca2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdatePinnedDialogs', 'UpdatePinnedDialogs'] = pydantic.Field(
        'types.UpdatePinnedDialogs',
        alias='_'
    )

    folder_id: typing.Optional[int] = None
    order: typing.Optional[list["base.DialogPeer"]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageBlockEmbed(BaseModel):
    """
    types.PageBlockEmbed
    ID: 0xa8718dc5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageBlockEmbed', 'PageBlockEmbed'] = pydantic.Field(
        'types.PageBlockEmbed',
        alias='_'
    )

    caption: "base.PageCaption"
    full_width: typing.Optional[bool] = None
    allow_scrolling: typing.Optional[bool] = None
    url: typing.Optional[str] = None
    html: typing.Optional[str] = None
    poster_photo_id: typing.Optional[int] = None
    w: typing.Optional[int] = None
    h: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputPrivacyRule - Layer 181
InputPrivacyRule = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputPrivacyValueAllowAll,
            pydantic.Tag('InputPrivacyValueAllowAll')
        ],
        typing.Annotated[
            types.InputPrivacyValueAllowChatParticipants,
            pydantic.Tag('InputPrivacyValueAllowChatParticipants')
        ],
        typing.Annotated[
            types.InputPrivacyValueAllowCloseFriends,
            pydantic.Tag('InputPrivacyValueAllowCloseFriends')
        ],
        typing.Annotated[
            types.InputPrivacyValueAllowContacts,
            pydantic.Tag('InputPrivacyValueAllowContacts')
        ],
        typing.Annotated[
            types.InputPrivacyValueAllowPremium,
            pydantic.Tag('InputPrivacyValueAllowPremium')
        ],
        typing.Annotated[
            types.InputPrivacyValueAllowUsers,
            pydantic.Tag('InputPrivacyValueAllowUsers')
        ],
        typing.Annotated[
            types.InputPrivacyValueDisallowAll,
            pydantic.Tag('InputPrivacyValueDisallowAll')
        ],
        typing.Annotated[
            types.InputPrivacyValueDisallowChatParticipants,
            pydantic.Tag('InputPrivacyValueDisallowChatParticipants')
        ],
        typing.Annotated[
            types.InputPrivacyValueDisallowContacts,
            pydantic.Tag('InputPrivacyValueDisallowContacts')
        ],
        typing.Annotated[
            types.InputPrivacyValueDisallowUsers,
            pydantic.Tag('InputPrivacyValueDisallowUsers')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ImportWebTokenAuthorization(BaseModel):
    """
    functions.auth.ImportWebTokenAuthorization
    ID: 0x2db873a9
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.ImportWebTokenAuthorization', 'ImportWebTokenAuthorization'] = pydantic.Field(
        'functions.auth.ImportWebTokenAuthorization',
        alias='_'
    )

    api_id: int
    api_hash: str
    web_auth_token: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.SentCode - Layer 181
SentCode = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.auth.SentCode,
            pydantic.Tag('auth.SentCode'),
            pydantic.Tag('SentCode')
        ],
        typing.Annotated[
            types.auth.SentCodeSuccess,
            pydantic.Tag('auth.SentCodeSuccess'),
            pydantic.Tag('SentCodeSuccess')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaDocument(BaseModel):
    """
    types.InputMediaDocument
    ID: 0x33473058
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaDocument', 'InputMediaDocument'] = pydantic.Field(
        'types.InputMediaDocument',
        alias='_'
    )

    id: "base.InputDocument"
    spoiler: typing.Optional[bool] = None
    ttl_seconds: typing.Optional[int] = None
    query: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MediaArea - Layer 181
MediaArea = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputMediaAreaChannelPost,
            pydantic.Tag('InputMediaAreaChannelPost')
        ],
        typing.Annotated[
            types.InputMediaAreaVenue,
            pydantic.Tag('InputMediaAreaVenue')
        ],
        typing.Annotated[
            types.MediaAreaChannelPost,
            pydantic.Tag('MediaAreaChannelPost')
        ],
        typing.Annotated[
            types.MediaAreaGeoPoint,
            pydantic.Tag('MediaAreaGeoPoint')
        ],
        typing.Annotated[
            types.MediaAreaSuggestedReaction,
            pydantic.Tag('MediaAreaSuggestedReaction')
        ],
        typing.Annotated[
            types.MediaAreaVenue,
            pydantic.Tag('MediaAreaVenue')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatAdminRights(BaseModel):
    """
    types.ChatAdminRights
    ID: 0x5fb224d5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChatAdminRights', 'ChatAdminRights'] = pydantic.Field(
        'types.ChatAdminRights',
        alias='_'
    )

    change_info: typing.Optional[bool] = None
    post_messages: typing.Optional[bool] = None
    edit_messages: typing.Optional[bool] = None
    delete_messages: typing.Optional[bool] = None
    ban_users: typing.Optional[bool] = None
    invite_users: typing.Optional[bool] = None
    pin_messages: typing.Optional[bool] = None
    add_admins: typing.Optional[bool] = None
    anonymous: typing.Optional[bool] = None
    manage_call: typing.Optional[bool] = None
    other: typing.Optional[bool] = None
    manage_topics: typing.Optional[bool] = None
    post_stories: typing.Optional[bool] = None
    edit_stories: typing.Optional[bool] = None
    delete_stories: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SearchGlobal(BaseModel):
    """
    functions.messages.SearchGlobal
    ID: 0x4bc6589a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SearchGlobal', 'SearchGlobal'] = pydantic.Field(
        'functions.messages.SearchGlobal',
        alias='_'
    )

    q: str
    filter: "base.MessagesFilter"
    min_date: Datetime
    max_date: Datetime
    offset_rate: int
    offset_peer: "base.InputPeer"
    offset_id: int
    limit: int
    broadcasts_only: typing.Optional[bool] = None
    folder_id: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UserStatusLastWeek(BaseModel):
    """
    types.UserStatusLastWeek
    ID: 0x541a1d1a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UserStatusLastWeek', 'UserStatusLastWeek'] = pydantic.Field(
        'types.UserStatusLastWeek',
        alias='_'
    )

    by_me: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AcceptUrlAuth(BaseModel):
    """
    functions.messages.AcceptUrlAuth
    ID: 0xb12c7125
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.AcceptUrlAuth', 'AcceptUrlAuth'] = pydantic.Field(
        'functions.messages.AcceptUrlAuth',
        alias='_'
    )

    write_allowed: typing.Optional[bool] = None
    peer: typing.Optional["base.InputPeer"] = None
    msg_id: typing.Optional[int] = None
    button_id: typing.Optional[int] = None
    url: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PeerColor(BaseModel):
    """
    types.PeerColor
    ID: 0xb54b5acf
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PeerColor', 'PeerColor'] = pydantic.Field(
        'types.PeerColor',
        alias='_'
    )

    color: typing.Optional[int] = None
    background_emoji_id: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotInlineQuery(BaseModel):
    """
    types.UpdateBotInlineQuery
    ID: 0x496f379c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotInlineQuery', 'UpdateBotInlineQuery'] = pydantic.Field(
        'types.UpdateBotInlineQuery',
        alias='_'
    )

    query_id: int
    user_id: int
    query: str
    offset: str
    geo: typing.Optional["base.GeoPoint"] = None
    peer_type: typing.Optional["base.InlineQueryPeerType"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetInlineGameScore(BaseModel):
    """
    functions.messages.SetInlineGameScore
    ID: 0x15ad9f64
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SetInlineGameScore', 'SetInlineGameScore'] = pydantic.Field(
        'functions.messages.SetInlineGameScore',
        alias='_'
    )

    id: "base.InputBotInlineMessageID"
    user_id: "base.InputUser"
    score: int
    edit_message: typing.Optional[bool] = None
    force: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class VideoSize(BaseModel):
    """
    types.VideoSize
    ID: 0xde33b094
    Layer: 181
    """
    QUALNAME: typing.Literal['types.VideoSize', 'VideoSize'] = pydantic.Field(
        'types.VideoSize',
        alias='_'
    )

    type: str
    w: int
    h: int
    size: int
    video_start_ts: typing.Optional[float] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MyBoost(BaseModel):
    """
    types.MyBoost
    ID: 0xc448415c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MyBoost', 'MyBoost'] = pydantic.Field(
        'types.MyBoost',
        alias='_'
    )

    slot: int
    date: Datetime
    expires: Datetime
    peer: typing.Optional["base.Peer"] = None
    cooldown_until_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageFwdHeader(BaseModel):
    """
    types.MessageFwdHeader
    ID: 0x4e4df4bb
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageFwdHeader', 'MessageFwdHeader'] = pydantic.Field(
        'types.MessageFwdHeader',
        alias='_'
    )

    date: Datetime
    imported: typing.Optional[bool] = None
    saved_out: typing.Optional[bool] = None
    from_id: typing.Optional["base.Peer"] = None
    from_name: typing.Optional[str] = None
    channel_post: typing.Optional[int] = None
    post_author: typing.Optional[str] = None
    saved_from_peer: typing.Optional["base.Peer"] = None
    saved_from_msg_id: typing.Optional[int] = None
    saved_from_id: typing.Optional["base.Peer"] = None
    saved_from_name: typing.Optional[str] = None
    saved_date: typing.Optional[Datetime] = None
    psa_type: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.CodeType - Layer 181
CodeType = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.auth.CodeTypeCall,
            pydantic.Tag('auth.CodeTypeCall'),
            pydantic.Tag('CodeTypeCall')
        ],
        typing.Annotated[
            types.auth.CodeTypeFlashCall,
            pydantic.Tag('auth.CodeTypeFlashCall'),
            pydantic.Tag('CodeTypeFlashCall')
        ],
        typing.Annotated[
            types.auth.CodeTypeFragmentSms,
            pydantic.Tag('auth.CodeTypeFragmentSms'),
            pydantic.Tag('CodeTypeFragmentSms')
        ],
        typing.Annotated[
            types.auth.CodeTypeMissedCall,
            pydantic.Tag('auth.CodeTypeMissedCall'),
            pydantic.Tag('CodeTypeMissedCall')
        ],
        typing.Annotated[
            types.auth.CodeTypeSms,
            pydantic.Tag('auth.CodeTypeSms'),
            pydantic.Tag('CodeTypeSms')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WebAuthorization(BaseModel):
    """
    types.WebAuthorization
    ID: 0xa6f8f452
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WebAuthorization', 'WebAuthorization'] = pydantic.Field(
        'types.WebAuthorization',
        alias='_'
    )

    hash: int
    bot_id: int
    domain: str
    browser: str
    platform: str
    date_created: Datetime
    date_active: Datetime
    ip: str
    region: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types

# auth.ExportedAuthorization - Layer 181
# NOTICE: This is a workaround for pydantic. Discriminated unions doesn't work with single type in Union
# pydantic.Discriminator(base_type_discriminator)
ExportedAuthorization = typing.Union[
    typing.Annotated[
        types.auth.ExportedAuthorization,
        pydantic.Tag('auth.ExportedAuthorization'),
        pydantic.Tag('ExportedAuthorization')
    ]
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BusinessBotRecipients(BaseModel):
    """
    types.BusinessBotRecipients
    ID: 0xb88cf373
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BusinessBotRecipients', 'BusinessBotRecipients'] = pydantic.Field(
        'types.BusinessBotRecipients',
        alias='_'
    )

    existing_chats: typing.Optional[bool] = None
    new_chats: typing.Optional[bool] = None
    contacts: typing.Optional[bool] = None
    non_contacts: typing.Optional[bool] = None
    exclude_selected: typing.Optional[bool] = None
    users: typing.Optional[list[int]] = None
    exclude_users: typing.Optional[list[int]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BotCallbackAnswer(BaseModel):
    """
    types.messages.BotCallbackAnswer
    ID: 0x36585ea4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.BotCallbackAnswer', 'BotCallbackAnswer'] = pydantic.Field(
        'types.messages.BotCallbackAnswer',
        alias='_'
    )

    cache_time: int
    alert: typing.Optional[bool] = None
    has_url: typing.Optional[bool] = None
    native_ui: typing.Optional[bool] = None
    message: typing.Optional[str] = None
    url: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelParticipantsMentions(BaseModel):
    """
    types.ChannelParticipantsMentions
    ID: 0xe04b5ceb
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelParticipantsMentions', 'ChannelParticipantsMentions'] = pydantic.Field(
        'types.ChannelParticipantsMentions',
        alias='_'
    )

    q: typing.Optional[str] = None
    top_msg_id: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PhoneCallProtocol(BaseModel):
    """
    types.PhoneCallProtocol
    ID: 0xfc878fc8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PhoneCallProtocol', 'PhoneCallProtocol'] = pydantic.Field(
        'types.PhoneCallProtocol',
        alias='_'
    )

    min_layer: int
    max_layer: int
    library_versions: list[str]
    udp_p2p: typing.Optional[bool] = None
    udp_reflector: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBusinessIntro(BaseModel):
    """
    types.InputBusinessIntro
    ID: 0x9c469cd
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBusinessIntro', 'InputBusinessIntro'] = pydantic.Field(
        'types.InputBusinessIntro',
        alias='_'
    )

    title: str
    description: str
    sticker: typing.Optional["base.InputDocument"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageStats(BaseModel):
    """
    types.stats.MessageStats
    ID: 0x7fe91c14
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stats.MessageStats', 'MessageStats'] = pydantic.Field(
        'types.stats.MessageStats',
        alias='_'
    )

    views_graph: "base.StatsGraph"
    reactions_by_emotion_graph: "base.StatsGraph"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SmsJob(BaseModel):
    """
    types.SmsJob
    ID: 0xe6a1eeb8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SmsJob', 'SmsJob'] = pydantic.Field(
        'types.SmsJob',
        alias='_'
    )

    job_id: str
    phone_number: str
    text: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DialogFolder(BaseModel):
    """
    types.DialogFolder
    ID: 0x71bd134c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.DialogFolder', 'DialogFolder'] = pydantic.Field(
        'types.DialogFolder',
        alias='_'
    )

    folder: "base.Folder"
    peer: "base.Peer"
    top_message: int
    unread_muted_peers_count: int
    unread_unmuted_peers_count: int
    unread_muted_messages_count: int
    unread_unmuted_messages_count: int
    pinned: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PollResults(BaseModel):
    """
    types.PollResults
    ID: 0x7adf2420
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PollResults', 'PollResults'] = pydantic.Field(
        'types.PollResults',
        alias='_'
    )

    min: typing.Optional[bool] = None
    results: typing.Optional[list["base.PollAnswerVoters"]] = None
    total_voters: typing.Optional[int] = None
    recent_voters: typing.Optional[list["base.Peer"]] = None
    solution: typing.Optional[str] = None
    solution_entities: typing.Optional[list["base.MessageEntity"]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ToggleStickerSets(BaseModel):
    """
    functions.messages.ToggleStickerSets
    ID: 0xb5052fea
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.ToggleStickerSets', 'ToggleStickerSets'] = pydantic.Field(
        'functions.messages.ToggleStickerSets',
        alias='_'
    )

    stickersets: list["base.InputStickerSet"]
    uninstall: typing.Optional[bool] = None
    archive: typing.Optional[bool] = None
    unarchive: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChatReactions - Layer 181
ChatReactions = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.ChatReactionsAll,
            pydantic.Tag('ChatReactionsAll')
        ],
        typing.Annotated[
            types.ChatReactionsNone,
            pydantic.Tag('ChatReactionsNone')
        ],
        typing.Annotated[
            types.ChatReactionsSome,
            pydantic.Tag('ChatReactionsSome')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputBotInlineMessage - Layer 181
InputBotInlineMessage = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputBotInlineMessageGame,
            pydantic.Tag('InputBotInlineMessageGame')
        ],
        typing.Annotated[
            types.InputBotInlineMessageMediaAuto,
            pydantic.Tag('InputBotInlineMessageMediaAuto')
        ],
        typing.Annotated[
            types.InputBotInlineMessageMediaContact,
            pydantic.Tag('InputBotInlineMessageMediaContact')
        ],
        typing.Annotated[
            types.InputBotInlineMessageMediaGeo,
            pydantic.Tag('InputBotInlineMessageMediaGeo')
        ],
        typing.Annotated[
            types.InputBotInlineMessageMediaInvoice,
            pydantic.Tag('InputBotInlineMessageMediaInvoice')
        ],
        typing.Annotated[
            types.InputBotInlineMessageMediaVenue,
            pydantic.Tag('InputBotInlineMessageMediaVenue')
        ],
        typing.Annotated[
            types.InputBotInlineMessageMediaWebPage,
            pydantic.Tag('InputBotInlineMessageMediaWebPage')
        ],
        typing.Annotated[
            types.InputBotInlineMessageText,
            pydantic.Tag('InputBotInlineMessageText')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageRelatedArticle(BaseModel):
    """
    types.PageRelatedArticle
    ID: 0xb390dc08
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageRelatedArticle', 'PageRelatedArticle'] = pydantic.Field(
        'types.PageRelatedArticle',
        alias='_'
    )

    url: str
    webpage_id: int
    title: typing.Optional[str] = None
    description: typing.Optional[str] = None
    photo_id: typing.Optional[int] = None
    author: typing.Optional[str] = None
    published_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputAppEvent(BaseModel):
    """
    types.InputAppEvent
    ID: 0x1d1b1245
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputAppEvent', 'InputAppEvent'] = pydantic.Field(
        'types.InputAppEvent',
        alias='_'
    )

    time: float
    type: str
    peer: int
    data: "base.JSONValue"



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.SavedRingtone - Layer 181
SavedRingtone = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.account.SavedRingtone,
            pydantic.Tag('account.SavedRingtone'),
            pydantic.Tag('SavedRingtone')
        ],
        typing.Annotated[
            types.account.SavedRingtoneConverted,
            pydantic.Tag('account.SavedRingtoneConverted'),
            pydantic.Tag('SavedRingtoneConverted')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageBlockChannel(BaseModel):
    """
    types.PageBlockChannel
    ID: 0xef1751b5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageBlockChannel', 'PageBlockChannel'] = pydantic.Field(
        'types.PageBlockChannel',
        alias='_'
    )

    channel: "base.Chat"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatAdminWithInvites(BaseModel):
    """
    types.ChatAdminWithInvites
    ID: 0xf2ecef23
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChatAdminWithInvites', 'ChatAdminWithInvites'] = pydantic.Field(
        'types.ChatAdminWithInvites',
        alias='_'
    )

    admin_id: int
    invites_count: int
    revoked_invites_count: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BlockFromReplies(BaseModel):
    """
    functions.contacts.BlockFromReplies
    ID: 0x29a8962c
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.contacts.BlockFromReplies', 'BlockFromReplies'] = pydantic.Field(
        'functions.contacts.BlockFromReplies',
        alias='_'
    )

    msg_id: int
    delete_message: typing.Optional[bool] = None
    delete_history: typing.Optional[bool] = None
    report_spam: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ContentSettings(BaseModel):
    """
    types.account.ContentSettings
    ID: 0x57e28221
    Layer: 181
    """
    QUALNAME: typing.Literal['types.account.ContentSettings', 'ContentSettings'] = pydantic.Field(
        'types.account.ContentSettings',
        alias='_'
    )

    sensitive_enabled: typing.Optional[bool] = None
    sensitive_can_change: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatFull(BaseModel):
    """
    types.ChatFull
    ID: 0x2633421b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChatFull', 'ChatFull'] = pydantic.Field(
        'types.ChatFull',
        alias='_'
    )

    id: int
    about: str
    participants: "base.ChatParticipants"
    notify_settings: "base.PeerNotifySettings"
    can_set_username: typing.Optional[bool] = None
    has_scheduled: typing.Optional[bool] = None
    translations_disabled: typing.Optional[bool] = None
    chat_photo: typing.Optional["base.Photo"] = None
    exported_invite: typing.Optional["base.ExportedChatInvite"] = None
    bot_info: typing.Optional[list["base.BotInfo"]] = None
    pinned_msg_id: typing.Optional[int] = None
    folder_id: typing.Optional[int] = None
    call: typing.Optional["base.InputGroupCall"] = None
    ttl_period: typing.Optional[int] = None
    groupcall_default_join_as: typing.Optional["base.Peer"] = None
    theme_emoticon: typing.Optional[str] = None
    requests_pending: typing.Optional[int] = None
    recent_requesters: typing.Optional[list[int]] = None
    available_reactions: typing.Optional["base.ChatReactions"] = None
    reactions_limit: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PasswordKdfAlgo - Layer 181
PasswordKdfAlgo = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow,
            pydantic.Tag('PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow')
        ],
        typing.Annotated[
            types.PasswordKdfAlgoUnknown,
            pydantic.Tag('PasswordKdfAlgoUnknown')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PeerSettings(BaseModel):
    """
    types.PeerSettings
    ID: 0xacd66c5e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PeerSettings', 'PeerSettings'] = pydantic.Field(
        'types.PeerSettings',
        alias='_'
    )

    report_spam: typing.Optional[bool] = None
    add_contact: typing.Optional[bool] = None
    block_contact: typing.Optional[bool] = None
    share_contact: typing.Optional[bool] = None
    need_contacts_exception: typing.Optional[bool] = None
    report_geo: typing.Optional[bool] = None
    autoarchived: typing.Optional[bool] = None
    invite_members: typing.Optional[bool] = None
    request_chat_broadcast: typing.Optional[bool] = None
    business_bot_paused: typing.Optional[bool] = None
    business_bot_can_reply: typing.Optional[bool] = None
    geo_distance: typing.Optional[int] = None
    request_chat_title: typing.Optional[str] = None
    request_chat_date: typing.Optional[Datetime] = None
    business_bot_id: typing.Optional[int] = None
    business_bot_manage_url: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InlineQueryPeerType - Layer 181
InlineQueryPeerType = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InlineQueryPeerTypeBotPM,
            pydantic.Tag('InlineQueryPeerTypeBotPM')
        ],
        typing.Annotated[
            types.InlineQueryPeerTypeBroadcast,
            pydantic.Tag('InlineQueryPeerTypeBroadcast')
        ],
        typing.Annotated[
            types.InlineQueryPeerTypeChat,
            pydantic.Tag('InlineQueryPeerTypeChat')
        ],
        typing.Annotated[
            types.InlineQueryPeerTypeMegagroup,
            pydantic.Tag('InlineQueryPeerTypeMegagroup')
        ],
        typing.Annotated[
            types.InlineQueryPeerTypePM,
            pydantic.Tag('InlineQueryPeerTypePM')
        ],
        typing.Annotated[
            types.InlineQueryPeerTypeSameBotPM,
            pydantic.Tag('InlineQueryPeerTypeSameBotPM')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Found(BaseModel):
    """
    types.contacts.Found
    ID: 0xb3134d9d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.contacts.Found', 'Found'] = pydantic.Field(
        'types.contacts.Found',
        alias='_'
    )

    my_results: list["base.Peer"]
    results: list["base.Peer"]
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetAdminLog(BaseModel):
    """
    functions.channels.GetAdminLog
    ID: 0x33ddf480
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.GetAdminLog', 'GetAdminLog'] = pydantic.Field(
        'functions.channels.GetAdminLog',
        alias='_'
    )

    channel: "base.InputChannel"
    q: str
    max_id: int
    min_id: int
    limit: int
    events_filter: typing.Optional["base.ChannelAdminLogEventsFilter"] = None
    admins: typing.Optional[list["base.InputUser"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.UserInfo - Layer 181
UserInfo = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.help.UserInfo,
            pydantic.Tag('help.UserInfo'),
            pydantic.Tag('UserInfo')
        ],
        typing.Annotated[
            types.help.UserInfoEmpty,
            pydantic.Tag('help.UserInfoEmpty'),
            pydantic.Tag('UserInfoEmpty')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.StickerSet - Layer 181
StickerSet = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.StickerSet,
            pydantic.Tag('messages.StickerSet'),
            pydantic.Tag('StickerSet')
        ],
        typing.Annotated[
            types.messages.StickerSetNotModified,
            pydantic.Tag('messages.StickerSetNotModified'),
            pydantic.Tag('StickerSetNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetAllStories(BaseModel):
    """
    functions.stories.GetAllStories
    ID: 0xeeb0d625
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stories.GetAllStories', 'GetAllStories'] = pydantic.Field(
        'functions.stories.GetAllStories',
        alias='_'
    )

    next: typing.Optional[bool] = None
    hidden: typing.Optional[bool] = None
    state: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelParticipantCreator(BaseModel):
    """
    types.ChannelParticipantCreator
    ID: 0x2fe601d3
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelParticipantCreator', 'ChannelParticipantCreator'] = pydantic.Field(
        'types.ChannelParticipantCreator',
        alias='_'
    )

    user_id: int
    admin_rights: "base.ChatAdminRights"
    rank: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GiveawayInfoResults(BaseModel):
    """
    types.payments.GiveawayInfoResults
    ID: 0xcd5570
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.GiveawayInfoResults', 'GiveawayInfoResults'] = pydantic.Field(
        'types.payments.GiveawayInfoResults',
        alias='_'
    )

    start_date: Datetime
    finish_date: Datetime
    winners_count: int
    activated_count: int
    winner: typing.Optional[bool] = None
    refunded: typing.Optional[bool] = None
    gift_code_slug: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChannelAdminLogEventAction - Layer 181
ChannelAdminLogEventAction = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeAbout,
            pydantic.Tag('ChannelAdminLogEventActionChangeAbout')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeAvailableReactions,
            pydantic.Tag('ChannelAdminLogEventActionChangeAvailableReactions')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeEmojiStatus,
            pydantic.Tag('ChannelAdminLogEventActionChangeEmojiStatus')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeEmojiStickerSet,
            pydantic.Tag('ChannelAdminLogEventActionChangeEmojiStickerSet')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeHistoryTTL,
            pydantic.Tag('ChannelAdminLogEventActionChangeHistoryTTL')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeLinkedChat,
            pydantic.Tag('ChannelAdminLogEventActionChangeLinkedChat')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeLocation,
            pydantic.Tag('ChannelAdminLogEventActionChangeLocation')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangePeerColor,
            pydantic.Tag('ChannelAdminLogEventActionChangePeerColor')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangePhoto,
            pydantic.Tag('ChannelAdminLogEventActionChangePhoto')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeProfilePeerColor,
            pydantic.Tag('ChannelAdminLogEventActionChangeProfilePeerColor')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeStickerSet,
            pydantic.Tag('ChannelAdminLogEventActionChangeStickerSet')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeTitle,
            pydantic.Tag('ChannelAdminLogEventActionChangeTitle')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeUsername,
            pydantic.Tag('ChannelAdminLogEventActionChangeUsername')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeUsernames,
            pydantic.Tag('ChannelAdminLogEventActionChangeUsernames')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionChangeWallpaper,
            pydantic.Tag('ChannelAdminLogEventActionChangeWallpaper')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionCreateTopic,
            pydantic.Tag('ChannelAdminLogEventActionCreateTopic')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionDefaultBannedRights,
            pydantic.Tag('ChannelAdminLogEventActionDefaultBannedRights')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionDeleteMessage,
            pydantic.Tag('ChannelAdminLogEventActionDeleteMessage')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionDeleteTopic,
            pydantic.Tag('ChannelAdminLogEventActionDeleteTopic')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionDiscardGroupCall,
            pydantic.Tag('ChannelAdminLogEventActionDiscardGroupCall')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionEditMessage,
            pydantic.Tag('ChannelAdminLogEventActionEditMessage')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionEditTopic,
            pydantic.Tag('ChannelAdminLogEventActionEditTopic')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionExportedInviteDelete,
            pydantic.Tag('ChannelAdminLogEventActionExportedInviteDelete')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionExportedInviteEdit,
            pydantic.Tag('ChannelAdminLogEventActionExportedInviteEdit')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionExportedInviteRevoke,
            pydantic.Tag('ChannelAdminLogEventActionExportedInviteRevoke')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantInvite,
            pydantic.Tag('ChannelAdminLogEventActionParticipantInvite')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantJoin,
            pydantic.Tag('ChannelAdminLogEventActionParticipantJoin')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantJoinByInvite,
            pydantic.Tag('ChannelAdminLogEventActionParticipantJoinByInvite')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantJoinByRequest,
            pydantic.Tag('ChannelAdminLogEventActionParticipantJoinByRequest')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantLeave,
            pydantic.Tag('ChannelAdminLogEventActionParticipantLeave')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantMute,
            pydantic.Tag('ChannelAdminLogEventActionParticipantMute')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantToggleAdmin,
            pydantic.Tag('ChannelAdminLogEventActionParticipantToggleAdmin')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantToggleBan,
            pydantic.Tag('ChannelAdminLogEventActionParticipantToggleBan')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantUnmute,
            pydantic.Tag('ChannelAdminLogEventActionParticipantUnmute')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionParticipantVolume,
            pydantic.Tag('ChannelAdminLogEventActionParticipantVolume')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionPinTopic,
            pydantic.Tag('ChannelAdminLogEventActionPinTopic')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionSendMessage,
            pydantic.Tag('ChannelAdminLogEventActionSendMessage')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionStartGroupCall,
            pydantic.Tag('ChannelAdminLogEventActionStartGroupCall')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionStopPoll,
            pydantic.Tag('ChannelAdminLogEventActionStopPoll')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionToggleAntiSpam,
            pydantic.Tag('ChannelAdminLogEventActionToggleAntiSpam')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionToggleForum,
            pydantic.Tag('ChannelAdminLogEventActionToggleForum')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionToggleGroupCallSetting,
            pydantic.Tag('ChannelAdminLogEventActionToggleGroupCallSetting')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionToggleInvites,
            pydantic.Tag('ChannelAdminLogEventActionToggleInvites')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionToggleNoForwards,
            pydantic.Tag('ChannelAdminLogEventActionToggleNoForwards')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionTogglePreHistoryHidden,
            pydantic.Tag('ChannelAdminLogEventActionTogglePreHistoryHidden')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionToggleSignatures,
            pydantic.Tag('ChannelAdminLogEventActionToggleSignatures')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionToggleSlowMode,
            pydantic.Tag('ChannelAdminLogEventActionToggleSlowMode')
        ],
        typing.Annotated[
            types.ChannelAdminLogEventActionUpdatePinned,
            pydantic.Tag('ChannelAdminLogEventActionUpdatePinned')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetPremiumGiftCodeOptions(BaseModel):
    """
    functions.payments.GetPremiumGiftCodeOptions
    ID: 0x2757ba54
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.payments.GetPremiumGiftCodeOptions', 'GetPremiumGiftCodeOptions'] = pydantic.Field(
        'functions.payments.GetPremiumGiftCodeOptions',
        alias='_'
    )

    boost_peer: typing.Optional["base.InputPeer"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WallPaper(BaseModel):
    """
    types.WallPaper
    ID: 0xa437c3ed
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WallPaper', 'WallPaper'] = pydantic.Field(
        'types.WallPaper',
        alias='_'
    )

    id: int
    access_hash: int
    slug: str
    document: "base.Document"
    creator: typing.Optional[bool] = None
    default: typing.Optional[bool] = None
    pattern: typing.Optional[bool] = None
    dark: typing.Optional[bool] = None
    settings: typing.Optional["base.WallPaperSettings"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class VideoSizeEmojiMarkup(BaseModel):
    """
    types.VideoSizeEmojiMarkup
    ID: 0xf85c413c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.VideoSizeEmojiMarkup', 'VideoSizeEmojiMarkup'] = pydantic.Field(
        'types.VideoSizeEmojiMarkup',
        alias='_'
    )

    emoji_id: int
    background_colors: list[int]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# updates.ChannelDifference - Layer 181
ChannelDifference = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.updates.ChannelDifference,
            pydantic.Tag('updates.ChannelDifference'),
            pydantic.Tag('ChannelDifference')
        ],
        typing.Annotated[
            types.updates.ChannelDifferenceEmpty,
            pydantic.Tag('updates.ChannelDifferenceEmpty'),
            pydantic.Tag('ChannelDifferenceEmpty')
        ],
        typing.Annotated[
            types.updates.ChannelDifferenceTooLong,
            pydantic.Tag('updates.ChannelDifferenceTooLong'),
            pydantic.Tag('ChannelDifferenceTooLong')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CheckGroupCall(BaseModel):
    """
    functions.phone.CheckGroupCall
    ID: 0xb59cf977
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.CheckGroupCall', 'CheckGroupCall'] = pydantic.Field(
        'functions.phone.CheckGroupCall',
        alias='_'
    )

    call: "base.InputGroupCall"
    sources: list[int]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.SentEncryptedMessage - Layer 181
SentEncryptedMessage = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.SentEncryptedFile,
            pydantic.Tag('messages.SentEncryptedFile'),
            pydantic.Tag('SentEncryptedFile')
        ],
        typing.Annotated[
            types.messages.SentEncryptedMessage,
            pydantic.Tag('messages.SentEncryptedMessage'),
            pydantic.Tag('SentEncryptedMessage')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputFileLocation(BaseModel):
    """
    types.InputFileLocation
    ID: 0xdfdaabe1
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputFileLocation', 'InputFileLocation'] = pydantic.Field(
        'types.InputFileLocation',
        alias='_'
    )

    volume_id: int
    local_id: int
    secret: int
    file_reference: Bytes



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetUnreadReactions(BaseModel):
    """
    functions.messages.GetUnreadReactions
    ID: 0x3223495b
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetUnreadReactions', 'GetUnreadReactions'] = pydantic.Field(
        'functions.messages.GetUnreadReactions',
        alias='_'
    )

    peer: "base.InputPeer"
    offset_id: int
    add_offset: int
    limit: int
    max_id: int
    min_id: int
    top_msg_id: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputMessage - Layer 181
InputMessage = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.InputMessageCallbackQuery,
            pydantic.Tag('InputMessageCallbackQuery')
        ],
        typing.Annotated[
            types.InputMessageID,
            pydantic.Tag('InputMessageID')
        ],
        typing.Annotated[
            types.InputMessagePinned,
            pydantic.Tag('InputMessagePinned')
        ],
        typing.Annotated[
            types.InputMessageReplyTo,
            pydantic.Tag('InputMessageReplyTo')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.StickerSetInstallResult - Layer 181
StickerSetInstallResult = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.StickerSetInstallResultArchive,
            pydantic.Tag('messages.StickerSetInstallResultArchive'),
            pydantic.Tag('StickerSetInstallResultArchive')
        ],
        typing.Annotated[
            types.messages.StickerSetInstallResultSuccess,
            pydantic.Tag('messages.StickerSetInstallResultSuccess'),
            pydantic.Tag('StickerSetInstallResultSuccess')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.DhConfig - Layer 181
DhConfig = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.DhConfig,
            pydantic.Tag('messages.DhConfig'),
            pydantic.Tag('DhConfig')
        ],
        typing.Annotated[
            types.messages.DhConfigNotModified,
            pydantic.Tag('messages.DhConfigNotModified'),
            pydantic.Tag('DhConfigNotModified')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StickerSet(BaseModel):
    """
    types.messages.StickerSet
    ID: 0x6e153f16
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.StickerSet', 'StickerSet'] = pydantic.Field(
        'types.messages.StickerSet',
        alias='_'
    )

    set: "base.StickerSet"
    packs: list["base.StickerPack"]
    keywords: list["base.StickerKeyword"]
    documents: list["base.Document"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MediaAreaCoordinates(BaseModel):
    """
    types.MediaAreaCoordinates
    ID: 0x3d1ea4e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MediaAreaCoordinates', 'MediaAreaCoordinates'] = pydantic.Field(
        'types.MediaAreaCoordinates',
        alias='_'
    )

    x: float
    y: float
    w: float
    h: float
    rotation: float



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Config(BaseModel):
    """
    types.Config
    ID: 0xcc1a241e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Config', 'Config'] = pydantic.Field(
        'types.Config',
        alias='_'
    )

    date: Datetime
    expires: Datetime
    test_mode: bool
    this_dc: int
    dc_options: list["base.DcOption"]
    dc_txt_domain_name: str
    chat_size_max: int
    megagroup_size_max: int
    forwarded_count_max: int
    online_update_period_ms: int
    offline_blur_timeout_ms: int
    offline_idle_timeout_ms: int
    online_cloud_timeout_ms: int
    notify_cloud_delay_ms: int
    notify_default_delay_ms: int
    push_chat_period_ms: int
    push_chat_limit: int
    edit_time_limit: int
    revoke_time_limit: int
    revoke_pm_time_limit: int
    rating_e_decay: int
    stickers_recent_limit: int
    channels_read_media_period: int
    call_receive_timeout_ms: int
    call_ring_timeout_ms: int
    call_connect_timeout_ms: int
    call_packet_timeout_ms: int
    me_url_prefix: str
    caption_length_max: int
    message_length_max: int
    webfile_dc_id: int
    default_p2p_contacts: typing.Optional[bool] = None
    preload_featured_stickers: typing.Optional[bool] = None
    revoke_pm_inbox: typing.Optional[bool] = None
    blocked_mode: typing.Optional[bool] = None
    force_try_ipv6: typing.Optional[bool] = None
    tmp_sessions: typing.Optional[int] = None
    autoupdate_url_prefix: typing.Optional[str] = None
    gif_search_username: typing.Optional[str] = None
    venue_search_username: typing.Optional[str] = None
    img_search_username: typing.Optional[str] = None
    static_maps_provider: typing.Optional[str] = None
    suggested_lang_code: typing.Optional[str] = None
    lang_pack_version: typing.Optional[int] = None
    base_lang_pack_version: typing.Optional[int] = None
    reactions_default: typing.Optional["base.Reaction"] = None
    autologin_token: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetConfig(BaseModel):
    """
    functions.help.GetConfig
    ID: 0xc4f9186b
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.help.GetConfig', 'GetConfig'] = pydantic.Field(
        'functions.help.GetConfig',
        alias='_'
    )




from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GroupCallParticipant(BaseModel):
    """
    types.GroupCallParticipant
    ID: 0xeba636fe
    Layer: 181
    """
    QUALNAME: typing.Literal['types.GroupCallParticipant', 'GroupCallParticipant'] = pydantic.Field(
        'types.GroupCallParticipant',
        alias='_'
    )

    peer: "base.Peer"
    date: Datetime
    source: int
    muted: typing.Optional[bool] = None
    left: typing.Optional[bool] = None
    can_self_unmute: typing.Optional[bool] = None
    just_joined: typing.Optional[bool] = None
    versioned: typing.Optional[bool] = None
    min: typing.Optional[bool] = None
    muted_by_you: typing.Optional[bool] = None
    volume_by_admin: typing.Optional[bool] = None
    is_self: typing.Optional[bool] = pydantic.Field(
        None,
        serialization_alias='self',
        validation_alias=pydantic.AliasChoices('self', 'is_self')
    )
    video_joined: typing.Optional[bool] = None
    active_date: typing.Optional[Datetime] = None
    volume: typing.Optional[int] = None
    about: typing.Optional[str] = None
    raise_hand_rating: typing.Optional[int] = None
    video: typing.Optional["base.GroupCallParticipantVideo"] = None
    presentation: typing.Optional["base.GroupCallParticipantVideo"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# RecentMeUrl - Layer 181
RecentMeUrl = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.RecentMeUrlChat,
            pydantic.Tag('RecentMeUrlChat')
        ],
        typing.Annotated[
            types.RecentMeUrlChatInvite,
            pydantic.Tag('RecentMeUrlChatInvite')
        ],
        typing.Annotated[
            types.RecentMeUrlStickerSet,
            pydantic.Tag('RecentMeUrlStickerSet')
        ],
        typing.Annotated[
            types.RecentMeUrlUnknown,
            pydantic.Tag('RecentMeUrlUnknown')
        ],
        typing.Annotated[
            types.RecentMeUrlUser,
            pydantic.Tag('RecentMeUrlUser')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class TextUrl(BaseModel):
    """
    types.TextUrl
    ID: 0x3c2884c1
    Layer: 181
    """
    QUALNAME: typing.Literal['types.TextUrl', 'TextUrl'] = pydantic.Field(
        'types.TextUrl',
        alias='_'
    )

    text: "base.RichText"
    url: str
    webpage_id: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChatPhoto - Layer 181
ChatPhoto = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.ChatPhoto,
            pydantic.Tag('ChatPhoto')
        ],
        typing.Annotated[
            types.ChatPhotoEmpty,
            pydantic.Tag('ChatPhotoEmpty')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatsSlice(BaseModel):
    """
    types.messages.ChatsSlice
    ID: 0x9cd81144
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.ChatsSlice', 'ChatsSlice'] = pydantic.Field(
        'types.messages.ChatsSlice',
        alias='_'
    )

    count: int
    chats: list["base.Chat"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Channel(BaseModel):
    """
    types.Channel
    ID: 0xaadfc8f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Channel', 'Channel'] = pydantic.Field(
        'types.Channel',
        alias='_'
    )

    id: int
    title: str
    photo: "base.ChatPhoto"
    date: Datetime
    creator: typing.Optional[bool] = None
    left: typing.Optional[bool] = None
    broadcast: typing.Optional[bool] = None
    verified: typing.Optional[bool] = None
    megagroup: typing.Optional[bool] = None
    restricted: typing.Optional[bool] = None
    signatures: typing.Optional[bool] = None
    min: typing.Optional[bool] = None
    scam: typing.Optional[bool] = None
    has_link: typing.Optional[bool] = None
    has_geo: typing.Optional[bool] = None
    slowmode_enabled: typing.Optional[bool] = None
    call_active: typing.Optional[bool] = None
    call_not_empty: typing.Optional[bool] = None
    fake: typing.Optional[bool] = None
    gigagroup: typing.Optional[bool] = None
    noforwards: typing.Optional[bool] = None
    join_to_send: typing.Optional[bool] = None
    join_request: typing.Optional[bool] = None
    forum: typing.Optional[bool] = None
    stories_hidden: typing.Optional[bool] = None
    stories_hidden_min: typing.Optional[bool] = None
    stories_unavailable: typing.Optional[bool] = None
    access_hash: typing.Optional[int] = None
    username: typing.Optional[str] = None
    restriction_reason: typing.Optional[list["base.RestrictionReason"]] = None
    admin_rights: typing.Optional["base.ChatAdminRights"] = None
    banned_rights: typing.Optional["base.ChatBannedRights"] = None
    default_banned_rights: typing.Optional["base.ChatBannedRights"] = None
    participants_count: typing.Optional[int] = None
    usernames: typing.Optional[list["base.Username"]] = None
    stories_max_id: typing.Optional[int] = None
    color: typing.Optional["base.PeerColor"] = None
    profile_color: typing.Optional["base.PeerColor"] = None
    emoji_status: typing.Optional["base.EmojiStatus"] = None
    level: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# UserStatus - Layer 181
UserStatus = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.UserStatusEmpty,
            pydantic.Tag('UserStatusEmpty')
        ],
        typing.Annotated[
            types.UserStatusLastMonth,
            pydantic.Tag('UserStatusLastMonth')
        ],
        typing.Annotated[
            types.UserStatusLastWeek,
            pydantic.Tag('UserStatusLastWeek')
        ],
        typing.Annotated[
            types.UserStatusOffline,
            pydantic.Tag('UserStatusOffline')
        ],
        typing.Annotated[
            types.UserStatusOnline,
            pydantic.Tag('UserStatusOnline')
        ],
        typing.Annotated[
            types.UserStatusRecently,
            pydantic.Tag('UserStatusRecently')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.SavedDialogs - Layer 181
SavedDialogs = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.SavedDialogs,
            pydantic.Tag('messages.SavedDialogs'),
            pydantic.Tag('SavedDialogs')
        ],
        typing.Annotated[
            types.messages.SavedDialogsNotModified,
            pydantic.Tag('messages.SavedDialogsNotModified'),
            pydantic.Tag('SavedDialogsNotModified')
        ],
        typing.Annotated[
            types.messages.SavedDialogsSlice,
            pydantic.Tag('messages.SavedDialogsSlice'),
            pydantic.Tag('SavedDialogsSlice')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GroupCallStreamChannel(BaseModel):
    """
    types.GroupCallStreamChannel
    ID: 0x80eb48af
    Layer: 181
    """
    QUALNAME: typing.Literal['types.GroupCallStreamChannel', 'GroupCallStreamChannel'] = pydantic.Field(
        'types.GroupCallStreamChannel',
        alias='_'
    )

    channel: int
    scale: int
    last_timestamp_ms: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PhotoSize - Layer 181
PhotoSize = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.PhotoCachedSize,
            pydantic.Tag('PhotoCachedSize')
        ],
        typing.Annotated[
            types.PhotoPathSize,
            pydantic.Tag('PhotoPathSize')
        ],
        typing.Annotated[
            types.PhotoSize,
            pydantic.Tag('PhotoSize')
        ],
        typing.Annotated[
            types.PhotoSizeEmpty,
            pydantic.Tag('PhotoSizeEmpty')
        ],
        typing.Annotated[
            types.PhotoSizeProgressive,
            pydantic.Tag('PhotoSizeProgressive')
        ],
        typing.Annotated[
            types.PhotoStrippedSize,
            pydantic.Tag('PhotoStrippedSize')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BroadcastRevenueStats(BaseModel):
    """
    types.stats.BroadcastRevenueStats
    ID: 0x5407e297
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stats.BroadcastRevenueStats', 'BroadcastRevenueStats'] = pydantic.Field(
        'types.stats.BroadcastRevenueStats',
        alias='_'
    )

    top_hours_graph: "base.StatsGraph"
    revenue_graph: "base.StatsGraph"
    balances: "base.BroadcastRevenueBalances"
    usd_rate: float



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelMessages(BaseModel):
    """
    types.messages.ChannelMessages
    ID: 0xc776ba4e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.ChannelMessages', 'ChannelMessages'] = pydantic.Field(
        'types.messages.ChannelMessages',
        alias='_'
    )

    pts: int
    count: int
    messages: list["base.Message"]
    topics: list["base.ForumTopic"]
    chats: list["base.Chat"]
    users: list["base.User"]
    inexact: typing.Optional[bool] = None
    offset_id_offset: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UploadRingtone(BaseModel):
    """
    functions.account.UploadRingtone
    ID: 0x831a83a2
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UploadRingtone', 'UploadRingtone'] = pydantic.Field(
        'functions.account.UploadRingtone',
        alias='_'
    )

    file: "base.InputFile"
    file_name: str
    mime_type: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChannelParticipantsFilter - Layer 181
ChannelParticipantsFilter = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.ChannelParticipantsAdmins,
            pydantic.Tag('ChannelParticipantsAdmins')
        ],
        typing.Annotated[
            types.ChannelParticipantsBanned,
            pydantic.Tag('ChannelParticipantsBanned')
        ],
        typing.Annotated[
            types.ChannelParticipantsBots,
            pydantic.Tag('ChannelParticipantsBots')
        ],
        typing.Annotated[
            types.ChannelParticipantsContacts,
            pydantic.Tag('ChannelParticipantsContacts')
        ],
        typing.Annotated[
            types.ChannelParticipantsKicked,
            pydantic.Tag('ChannelParticipantsKicked')
        ],
        typing.Annotated[
            types.ChannelParticipantsMentions,
            pydantic.Tag('ChannelParticipantsMentions')
        ],
        typing.Annotated[
            types.ChannelParticipantsRecent,
            pydantic.Tag('ChannelParticipantsRecent')
        ],
        typing.Annotated[
            types.ChannelParticipantsSearch,
            pydantic.Tag('ChannelParticipantsSearch')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReplaceSticker(BaseModel):
    """
    functions.stickers.ReplaceSticker
    ID: 0x4696459a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stickers.ReplaceSticker', 'ReplaceSticker'] = pydantic.Field(
        'functions.stickers.ReplaceSticker',
        alias='_'
    )

    sticker: "base.InputDocument"
    new_sticker: "base.InputStickerSetItem"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StartScheduledGroupCall(BaseModel):
    """
    functions.phone.StartScheduledGroupCall
    ID: 0x5680e342
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.StartScheduledGroupCall', 'StartScheduledGroupCall'] = pydantic.Field(
        'functions.phone.StartScheduledGroupCall',
        alias='_'
    )

    call: "base.InputGroupCall"



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.Messages - Layer 181
Messages = typing.Annotated[
    typing.Union[
        typing.Annotated[
            types.messages.ChannelMessages,
            pydantic.Tag('messages.ChannelMessages'),
            pydantic.Tag('ChannelMessages')
        ],
        typing.Annotated[
            types.messages.Messages,
            pydantic.Tag('messages.Messages'),
            pydantic.Tag('Messages')
        ],
        typing.Annotated[
            types.messages.MessagesNotModified,
            pydantic.Tag('messages.MessagesNotModified'),
            pydantic.Tag('MessagesNotModified')
        ],
        typing.Annotated[
            types.messages.MessagesSlice,
            pydantic.Tag('messages.MessagesSlice'),
            pydantic.Tag('MessagesSlice')
        ]
    ],
    pydantic.Discriminator(base_type_discriminator)
]
